Index: trunk/ippTools/src/chiptool.c
===================================================================
--- trunk/ippTools/src/chiptool.c	(revision 6220)
+++ trunk/ippTools/src/chiptool.c	(revision 6221)
@@ -53,5 +53,5 @@
     psArray *rawFrames = p2searchRawFrames(config);
     if (!rawFrames) {
-        psError(PS_ERR_UNKNOWN, false, "no ppRawFrames found");
+        psError(PS_ERR_UNKNOWN, false, "no rawScienceFrames found");
         return false;
     }
@@ -74,5 +74,5 @@
     psArray *rawFrames = p2searchRawFrames(config);
     if (!rawFrames) {
-        psError(PS_ERR_UNKNOWN, false, "no ppRawFrames found");
+        psError(PS_ERR_UNKNOWN, false, "no rawScienceFrames found");
         return false;
     }
@@ -84,5 +84,5 @@
     if (pendingFrames) {
         for (int i = 0; i < rawFrames->n; i++) {
-            ppRawFrame *rawFrame = rawFrames->data[i];
+            rawScienceFrame *rawFrame = rawFrames->data[i];
             for (int j = 0; j < pendingFrames->n; j++) {
                 p2PendingFrame *pendingFrame = pendingFrames->data[j];
@@ -104,5 +104,5 @@
     if (doneFrames && (rawFrames->n > 0)) {
         for (int i = 0; i < rawFrames->n; i++) {
-            ppRawFrame *rawFrame = rawFrames->data[i];
+            rawScienceFrame *rawFrame = rawFrames->data[i];
             for (int j = 0; j < pendingFrames->n; j++) {
                 p2DoneFrame *doneFrame = pendingFrames->data[j];
@@ -122,5 +122,5 @@
 
     if (!rawFrames->n > 0) {
-        psError(PS_ERR_UNKNOWN, false, "no unprocessed ppRawFrames found");
+        psError(PS_ERR_UNKNOWN, false, "no unprocessed rawScienceFrames found");
         psFree(rawFrames);
         return false;
Index: trunk/ippTools/src/p2insertPendingFrames.c
===================================================================
--- trunk/ippTools/src/p2insertPendingFrames.c	(revision 6220)
+++ trunk/ippTools/src/p2insertPendingFrames.c	(revision 6221)
@@ -10,5 +10,5 @@
     // can we use p2rawToPending() here?
     for (int i = 0; i < rawFrames->n; i++) {
-        ppRawFrame *rawFrame = rawFrames->data[i];
+        rawScienceFrame *rawFrame = rawFrames->data[i];
 
         // find the next available version numbers
Index: trunk/ippTools/src/p2rawToPending.c
===================================================================
--- trunk/ippTools/src/p2rawToPending.c	(revision 6220)
+++ trunk/ippTools/src/p2rawToPending.c	(revision 6221)
@@ -10,5 +10,5 @@
 
     for (int i = 0; i < rawFrames->n; i++) {
-        ppRawFrame *rawFrame = rawFrames->data[i];
+        rawScienceFrame *rawFrame = rawFrames->data[i];
 
         p2PendingExpRow *pendingExposure = p2PendingExpRowAlloc(
Index: trunk/ippTools/src/p2searchDoneFrames.c
===================================================================
--- trunk/ippTools/src/p2searchDoneFrames.c	(revision 6220)
+++ trunk/ippTools/src/p2searchDoneFrames.c	(revision 6221)
@@ -13,5 +13,5 @@
     }
 
-    // output array of ppRawFrame
+    // output array of rawScienceFrame
     psArray *frames = psArrayAlloc(exposures->n);
     frames->n = 0;
Index: trunk/ippTools/src/pxalloc.c
===================================================================
--- trunk/ippTools/src/pxalloc.c	(revision 6220)
+++ trunk/ippTools/src/pxalloc.c	(revision 6221)
@@ -1,20 +1,20 @@
 #include "pxtools.h"
 
-static void ppRawFrameFree(ppRawFrame *ptr);
+static void rawScienceFrameFree(rawScienceFrame *ptr);
 static void p2PendingFrameFree(p2PendingFrame *ptr);
 static void p2DoneFrameFree(p2DoneFrame *ptr);
 
-ppRawFrame *ppRawFrameAlloc(
+rawScienceFrame *rawScienceFrameAlloc(
     rawScienceExpRow *exposure,
     psArray *images
 )
 {
-    ppRawFrame *frame;
+    rawScienceFrame *frame;
 
     PS_ASSERT_PTR_NON_NULL(exposure, NULL);
     PS_ASSERT_PTR_NON_NULL(images, NULL);
 
-    frame = psAlloc(sizeof(ppRawFrame));
-    psMemSetDeallocator(frame, (psFreeFunc)ppRawFrameFree);
+    frame = psAlloc(sizeof(rawScienceFrame));
+    psMemSetDeallocator(frame, (psFreeFunc)rawScienceFrameFree);
 
     frame->exposure = exposure;
@@ -24,5 +24,5 @@
 }
 
-static void ppRawFrameFree(ppRawFrame *ptr)
+static void rawScienceFrameFree(rawScienceFrame *ptr)
 {
     psFree(ptr->exposure);
Index: trunk/ippTools/src/pxtools.h
===================================================================
--- trunk/ippTools/src/pxtools.h	(revision 6220)
+++ trunk/ippTools/src/pxtools.h	(revision 6221)
@@ -50,7 +50,7 @@
     rawScienceExpRow *exposure;
     psArray *images;
-} ppRawFrame;
+} rawScienceFrame;
 
-ppRawFrame *ppRawFrameAlloc(
+rawScienceFrame *rawScienceFrameAlloc(
     rawScienceExpRow *exposure,
     psArray *images
@@ -81,4 +81,5 @@
 bool pxAdminConfig (pxConfig *config, int argc, char **argv);
 bool p2searchConfig (pxConfig *config, int argc, char **argv);
+
 psArray *p2rawToPending (pxConfig *config, psArray *rawFrames);
 psArray *p2searchRawFrames (pxConfig *config);

Index: trunk/ippTools/src/p2searchRawFrames.c
===================================================================
--- trunk/ippTools/src/p2searchRawFrames.c	(revision 6220)
+++ trunk/ippTools/src/p2searchRawFrames.c	(revision 6221)
@@ -13,5 +13,5 @@
     }
 
     // output array of ppRawFrame
     psArray *frames = psArrayAlloc(exposures->n);
     frames->n = 0;
@@ -33,5 +33,5 @@
         }
 
-        ppRawFrame *rawFrame = ppRawFrameAlloc(exposure, images);
+        rawScienceFrame *rawFrame = rawScienceFrameAlloc(exposure, images);
         psArrayAdd(frames, 100, rawFrame);
     }
@@ -13,5 +13,5 @@
     }
 
-    // output array of ppRawFrame
+    // output array of rawScienceFrame
     psArray *frames = psArrayAlloc(exposures->n);
     frames->n = 0;